/******************************************************************************
*******************************************************************************
	bullet rel DS
	relminator (Richard Eric M. Lope BSN RN)
	http://rel.betterwebber.com


	
*******************************************************************************
******************************************************************************/

#include <vector>

#include <nds.h>
#include <stdio.h>
#include <math.h>
#include <string.h>

#include "Cglsprite.h"
#include "Cgl2d.h"

#include "cearn_atan.h"
#include "Caabb.h"
#include "Cobject.h"
#include "Cbullet.h"
#include "Cturret.h"



// GRIT headers
#include "main_sprites.h"

// Texture packer headers
#include "uvcoord_main_sprites.h"


#define  FP_PI 16384 
#define  NUM_BULLETS 512
#define  MAX_TURRETS 16

using namespace std;

const int BULLET_SPEED =  0.75 * (1 << 12); 

void init_gl_screen();

void barrage_rings(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;				// non-fp
	tp.y_radius				= 9;				// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/64;			// + rotation speed
	tp.angle_dir			= 1;				// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/8;			// distance of each bullet on a spread
	tp.bullets_per_shot		= 8;
	tp.rotation_type		= 3;				// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;				// non-fp
	tp.max_spawn_delay		= 40;				// non-fp
	
	tp.wavemode				= EWM_SPRAY_TARGET;
	
	tp.wave_counter			= 0;				// non-fp
	tp.max_wave				= 0;				// non-fp maximum bullets per wave
	tp.max_wave_delay		= 8;				// non-fp maximum delay for next shot in a wave

	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED/4;
	tp.bp.speed_delta		= 0;				// floattof32(-0.950) if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(0.1);	//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= 20;				// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;				// non-fp
	tp.bp.state				= EB_ACCEL;			// normal, accelerator or inv accelerator
	tp.bp.smart				= true;				// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 80;				// non-fp
	tp.bp.num_frames		= 4;				// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;				// non-fp
	
	turret.parameters.push_back(tp);
}

void barrage_4way(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/64;				// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/4;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 4;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 10;					// non-fp
	

	tp.wavemode				= EWM_SPRAY_NORMAL;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 1;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 4;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED/4;
	tp.bp.speed_delta		= 0;					// floattof32(-0.950) if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(0.1);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= -1;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_ACCEL;				// normal, accelerator or inv accelerator
	tp.bp.smart				= false;				// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 70;					// non-fp
	tp.bp.num_frames		= 3;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp

	turret.parameters.push_back(tp);
	
}


void barrage_spray(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/32;				// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/32;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 8;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 30;					// non-fp
	
	tp.wavemode				= EWM_SPREAD_OFFSET;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 4;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 4;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED*6;
	tp.bp.speed_delta		= floattof32(-0.20950); //if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(0.5);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= -1;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_INVACCEL;			// normal, accelerator or inv accelerator
	tp.bp.smart				= false;				// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 58;					// non-fp
	tp.bp.num_frames		= 8;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp

	turret.parameters.push_back(tp);
	
}

void barrage_spray_delta(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/32;				// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/8;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 8;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 40;					// non-fp
	
	tp.wavemode				= EWM_SPRAY_NORMAL;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 3;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 8;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED/4;
	tp.bp.speed_delta		= floattof32(0); 		//if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(0.5);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= 20;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_ACCEL;				// normal, accelerator or inv accelerator
	tp.bp.smart				= true;					// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 54;					// non-fp
	tp.bp.num_frames		= 4;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp
	
	turret.parameters.push_back(tp);
	
}


void barrage_4way_rotate(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= false;				// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/16;
	tp.angle_speed			= 32768/64;			// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/6;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 6;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 8;					// non-fp
	
	tp.wavemode				= EWM_SPRAY_NORMAL;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 0;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 8;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED*3;
	tp.bp.speed_delta		= floattof32(0); 		//if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(1);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= -1;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_NORMAL;			// normal, accelerator or inv accelerator
	tp.bp.smart				= false;				// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 76;					// non-fp
	tp.bp.num_frames		= 4;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp
	
	turret.parameters.push_back(tp);
	
}

void barrage_wasak_delta(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/32;				// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/64;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 8;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 40;					// non-fp
	
	tp.wavemode				= EWM_SPREAD_OFFSET;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 6;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 4;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED/12;
	tp.bp.speed_delta		= floattof32(0.205); 		//if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(0.35);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= -1;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_ACCEL;				// normal, accelerator or inv accelerator
	tp.bp.smart				= true;					// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 50;					// non-fp
	tp.bp.num_frames		= 4;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp
	
	turret.parameters.push_back(tp);
	
}

void barrage_wasak_centered(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/32;				// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/32;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 5;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 30;					// non-fp
	
	tp.wavemode				= EWM_SPRAY_CENTERED;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 3;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 8;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED/2;
	tp.bp.speed_delta		= floattof32(-0.205); 		//if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(1);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= -1;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_ACCEL;				// normal, accelerator or inv accelerator
	tp.bp.smart				= false;					// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 73;					// non-fp
	tp.bp.num_frames		= 3;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp
	
	turret.parameters.push_back(tp);
	
}

void barrage_wasak_centered_reverse(Cturret &turret, int active_time, int x, int y)
{

	Tturret_params tp;
	
	// turret
	tp.active_time			= active_time; 
	tp.active				= true;					// non-fp
	tp.smart				= true;					// if targeting or not
	tp.x					= x << 12;
	tp.y					= y << 12;
	tp.dx					= 0;
	tp.dy					= 0;
	tp.x_radius				= 10;					// non-fp
	tp.y_radius				= 9;					// non-fp
	tp.angle				= 0;
	tp.min_angle			= 0;
	tp.max_angle			= 32767/1;
	tp.angle_speed			= 32768/32;				// + rotation speed
	tp.angle_dir			= 1;					// -1 or +1  determines rotation direction
	tp.spread_angle			= 32768/32;				// distance of each bullet on a spread
	tp.bullets_per_shot		= 5;
	tp.rotation_type		= 2;					// non-fp, whether back anf forth or not
	tp.spawn_delay			= 0;					// non-fp
	tp.max_spawn_delay		= 30;					// non-fp
	
	tp.wavemode				= EWM_SPRAY_CENTERED;
	
	tp.wave_counter			= 0;					// non-fp
	tp.max_wave				= 3;					// non-fp maximum bullets per wave
	tp.max_wave_delay		= 8;					// non-fp maximum delay for next shot in a wave
	
	// bullets
	tp.bp.x					= 0;
	tp.bp.y					= 0;
	tp.bp.speed				= BULLET_SPEED/2;
	tp.bp.speed_delta		= floattof32(0.205); 		//if the bullet speed per wave is variable
	tp.bp.offset			= floattof32(1);		//floattof32(1) // 1 << 12 for normal; Angle offset of each alternate bullet wave
	tp.bp.gx				= 0;
	tp.bp.gy				= 0;
	tp.bp.delay				= -1;					// for changing behavior. ie: normal to target (note that EB_NORMAL can be targeting at start via turret)
	tp.bp.energy			= 0;					// non-fp
	tp.bp.state				= EB_ACCEL;				// normal, accelerator or inv accelerator
	tp.bp.smart				= false;					// targeting or not (after counter == delay); 			
	
	tp.bp.start_frame		= 66;					// non-fp
	tp.bp.num_frames		= 4;					// non-fp
	tp.bp.anim_delay		= 3;
	tp.bp.death_ID			= 0;					// non-fp
	
	turret.parameters.push_back(tp);
	
}

/******************************************************************************
*******************************************************************************
	MAIN entry point


*******************************************************************************
******************************************************************************/




Cglsprite main_sprites[MAIN_SPRITES_NUM_IMAGES];	//  number of frames


Cgl2d gl2d;


	

int turret_spawn = 0;
int turret_spawn_delay = 555;
int turret_type = 0;
unsigned int turret_index = 0;
unsigned int num_turrets = MAX_TURRETS;



Tcoord target;

Cbullet_array bullets;

Cturret *turrets;
int main()
{
	
	
	turrets = new Cturret[MAX_TURRETS];
	
	int typer = 0;
	for (int i=0; i < MAX_TURRETS; i++)
	{
		int at = qran_range(200,1000);
		int x = qran_range(20,236);
		int y = qran_range(20,170);
		
		typer = i % 5;
		switch (typer)
		{
			case 1:
				barrage_wasak_delta(turrets[i],at,x,y);
				barrage_wasak_centered(turrets[i],at,x,y);
				barrage_wasak_centered_reverse(turrets[i],at,x,y);
				barrage_rings(turrets[i],at,x,y);
				barrage_spray(turrets[i],at,x,y);
				barrage_spray_delta(turrets[i],at,x,y);
				barrage_4way_rotate(turrets[i],at,x,y);
				barrage_4way(turrets[i],at,x,y);
				break;
			case 2:
				barrage_4way(turrets[i],at,x,y);
				barrage_spray(turrets[i],at,x,y);
				barrage_rings(turrets[i],at,x,y);
				barrage_wasak_delta(turrets[i],at,x,y);
				barrage_4way_rotate(turrets[i],at,x,y);
				break;
			case 3:
				barrage_spray_delta(turrets[i],at,x,y);
				barrage_4way_rotate(turrets[i],at,x,y);
				barrage_rings(turrets[i],at,x,y);
				barrage_wasak_centered(turrets[i],at,x,y);
				barrage_wasak_centered_reverse(turrets[i],at,x,y);
				break;
			case 4:
				barrage_spray(turrets[i],at,x,y);
				barrage_rings(turrets[i],at,x,y);
				barrage_wasak_centered_reverse(turrets[i],at,x,y);
				barrage_spray_delta(turrets[i],at,x,y);
				barrage_4way_rotate(turrets[i],at,x,y);
				break;
			default:
				barrage_spray_delta(turrets[i],at,x,y);
				barrage_4way_rotate(turrets[i],at,x,y);
				barrage_spray(turrets[i],at,x,y);
				barrage_rings(turrets[i],at,x,y);
				barrage_4way(turrets[i],at,x,y);
				break;
		}	
		
		
		turrets[i].init(turrets[i].parameters[0], bullets.p_bullets);
		turrets[i].set_target(&target);
		//turrets[i].set_target(128,96);
	}
	
	

	videoSetMode(MODE_5_3D);
	
	
	consoleDemoInit();
	
	iprintf("\x1b[1;1HBullet Rel DS");

	init_gl_screen();
	
	
	vramSetBankA(VRAM_A_TEXTURE);		// 128 kb -> main_sprites(64kb) and enemies(64kb) 
	
	// main sprites
	int main_sprites_textureID;  
	gl2d.load_texture(main_sprites_textureID,GL_RGB256, TEXTURE_SIZE_256 , TEXTURE_SIZE_256, (u8*)main_spritesBitmap);

	// load global pal
	// texture pal in VRAM_E?
	gluTexLoadPal(main_spritesPal, 512,GL_RGB256);

		
	// init sprites
	gl2d.init_sprites(main_sprites, MAIN_SPRITES_NUM_IMAGES, main_sprites_texcoords, main_sprites_textureID);
	
	int total_frame = 0;
	int frame = 0;
	int key;

	while(1)
	{
	
		scanKeys();
		key = keysDown();
		total_frame++;
		frame = (frame + 64) & 32767;
		
		if (key & KEY_B)
		{
			if (num_turrets > 0)
			{
				num_turrets--;	
			}
		}
		
		if (key & KEY_A)
		{
			if (num_turrets < MAX_TURRETS)
			{
				num_turrets++;	
			}
		}
		
		target.x = ( (128 << 12) + ((cosLerp(frame) + sinLerp(frame*3)) * 60)) >> 12;
		target.y = ( (96 << 12) + ((sinLerp(-frame*2) + sinLerp(frame*4)) * 40)) >> 12;
	
		for (int i=0; i < (int)num_turrets; i++)
			turrets[i].update();
		
		bullets.update();
		
		// start 2d mode
		gl2d.start();
			
			// needs to be called before texturing
			// or sprite gets blended by last glcolor call
			glColor(ARGB16(1,31,31,31)); 
			
			bullets.render_bullets(main_sprites);
			// draw target
			main_sprites[17].render(target.x, target.y);
			
		gl2d.end();
		
		
		
		
	
		glFlush(0);

		swiWaitForVBlank();
		
		//consoleClear();
		iprintf("\x1b[2;1HKey A  => Add Turret");
		iprintf("\x1b[3;1HKey B  => Remove Turret");
		iprintf("\x1b[6;1HBullets on screen = %i bullets ", bullets.active_bullets);
		iprintf("\x1b[7;1HNum_turrets       = %i turrets ", num_turrets);
		
	}

	
	return 0;
	
}



void init_gl_screen()
{

	// initialize gl
	glInit();
	
	//enable textures
	glEnable(GL_TEXTURE_2D);
	
	// enable antialiasing
	glEnable(GL_ANTIALIAS);
		
	// setup the rear plane
	glClearColor(0,0,0,31); // BG must be opaque for AA to work
	glClearPolyID(63); // BG must have a unique polygon ID for AA to work
	
	glClearDepth(GL_MAX_DEPTH);

	//this should work the same as the normal gl call
	glViewport(0,0,255,191);
	
	
	//any floating point gl call is being converted to fixed prior to being implemented
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluPerspective(70, 256.0 / 192.0, 1, 200);
	
	gluLookAt(	0.0, 0.0, 1.0,		//camera possition 
				0.0, 0.0, 0.0,		//look at
				0.0, 1.0, 0.0);		//up

	glMaterialf(GL_AMBIENT, RGB15(31,31,31));
	glMaterialf(GL_DIFFUSE, RGB15(31,31,31));
	glMaterialf(GL_SPECULAR, BIT(15) | RGB15(31,31,31));
	glMaterialf(GL_EMISSION, RGB15(31,31,31));

	//ds uses a table for shinyness..this generates a half-ass one
	glMaterialShinyness();

	//not a real gl function and will likely change
	glPolyFmt(POLY_ALPHA(31) | POLY_CULL_BACK);
}

